/*
 * Dispatcher.java
 *
 * Created on 9 July 2002, 15:27
 */

import java.util.*;

/**
 * Dispatches processes using a modified LIFO approach.
 * You will have to scatter "synchronized" keywords carefully through here.
 *
 * @author
 */
public class Dispatcher {

    /** The reference to the main window.
     * By keeping a reference the main window can be asked
     * to modify its display in order to keep it showing the current process states. */
    private A1 mainWindow;
    private Stack stack = new Stack();

    /** Creates a new instance of Dispatcher.
     * @param window the assignment window
     */
    public Dispatcher(A1 window) {
        mainWindow = window;
    }

    /**
     * Stops or starts the system.
     * @param pause whether the system should be paused or not
     */
    public void pauseSystem(boolean pause) {
    }

    /** Adds a new process to the stack.
     * @param process the new process
     */
    public void submitProcess(A1Process process) {
	if (!stack.isEmpty()){
		makeProcessWait((A1Process)stack.lastElement());
	}
	stack.push(process);
    }

    /**
     * Makes a process the running process.
     * It moves the process to the top of the stack.
     * The process at the top of the stack is the running process.
     * @param process the process to make running
     */
    public void makeProcessRun(A1Process process) {
	process.dispatchProcess();
    }

    /**
     * Called when a process is waiting for input.
     * i.e. it is waiting not ready.
     * @param process the waiting process
     */
    public void makeProcessWait(A1Process process) {
	process.interruptProcess();
    }

    /**
     * Called when a process that was waiting has received its input.
     * Makes the process run.
     * @param process the process to wake up
     */
    public void wakeProcess(A1Process process) {
    }

    /**
     * Called when a process has finished.
     * @param process the finished process
     */
    public void finishedProcess(A1Process process) {
	stack.pop();
    }

    /**
     * Kills the currently running process (if there is one).
     */
    public synchronized void killRunningProcess() {
    	stack.pop();
    }

}
