/*
 * ProcessArea.java
 *
 * Created on 9 July 2002, 11:40
 */

import java.awt.event.*;
import javax.swing.*;
import java.awt.Dimension;

/**
 * A scroll area associated with a process.
 *
 * @author  Robert Sheehan
 */
public class ProcessArea extends JScrollPane {
    
    /** The process associated with this area. */
    private A1Process process;
    /** The text area showing the process IO. */
    private JTextArea textArea;
    /** The standard size for a ProcessArea. */
    private static final Dimension SIZE = new Dimension(300, 80);
    
    /** Creates a new instance of ProcessArea.
     * @param mainWindow the window this is part of
     * @param interactive whether the process is to be interactive or not
     */
    public ProcessArea(final A1 mainWindow, boolean interactive) {
        textArea = new JTextArea();
        textArea.setEditable(false);
        setViewportView(textArea);
        setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
        // this is where the processes are created
        process =  interactive ? (A1Process)( new Interactive(this)) : (A1Process)(new Background(this));
        textArea.addMouseListener(new MouseAdapter() {
            public void mousePressed(MouseEvent e) {
                mainWindow.catchFocusChange(process);
            }
        });
    }
    
    /** Getter for property process.
     * @return Value of property process.
     */
    public A1Process getProcess() {
        return process;
    }
    
    /** Used by the IOSystem to print output from the process.
     * @return the text area of the process.
     */
    public JTextArea getTextArea() {
        return textArea;
    }
        
    public Dimension getMaximumSize() {
        return SIZE;
    }
}
